
TODO_11_77_28_50: provide and assert Tab-suggestions in all responses

Currently, schema already allows this: ArgValues <- InterpResult <- InvocationInput.

All tests can start asserting ArgValues for any requests.

Also, print suggestion on `ServerAction.DescribeLineArgs`.

